@@ -1,4 +1,5 @@
 use cosmwasm_std::StdError;
+use cw0::Expiration;
 use thiserror::Error;
 
 #[derive(Error, Debug, PartialEq)]
@@ -35,6 +36,15 @@ pub enum ContractError {
 
     #[error("Set withdraw address is not allowed")]
     WithdrawAddrPerm {},
+
+    #[error("Unsupported message")]
+    UnsupportedMessage {},
+
+    #[error("Allowance already expired while setting: {0}")]
+    SettingExpiredAllowance(Expiration),
+
+    #[error("Semver parsing error: {0}")]
+    SemVer(String),
 }
 
 impl From<cw1_whitelist::ContractError> for ContractError {
@@ -45,3 +55,9 @@ impl From<cw1_whitelist::ContractError> for ContractError {
         }
     }
 }
+
+impl From<semver::Error> for ContractError {
+    fn from(err: semver::Error) -> Self {
+        Self::SemVer(err.to_string())
+    }
+}
